@@ -1,5 +1,3 @@
-from decimal import Decimal
-from decimal import Context
 
 def binary_decompose(value):
     values = set()
@@ -44,22 +42,4 @@ def float_split(value, precision=7):
     return sign, int_value, float_value
 
 
-if hasattr(int, "from_bytes"):
-    from_bytes = int.from_bytes
-else:
-    def from_bytes(value_bytes, byteorder="big"):
-        t = 0
-        if byteorder.lower() != "big":
-            value_bytes = bytearray(value_bytes)
-            value_bytes.reverse()
-        else:
-            value_bytes = bytearray(value_bytes)
-        for x in value_bytes:
-            t = t*256 + x
-        return t
-
-
-try:
-    NUMERIC_TYPES = (int, long, float)
-except NameError:
-    NUMERIC_TYPES = (int, float)
+NUMERIC_TYPES = (int, float)
