@@ -7,21 +7,10 @@ import os
 import threading
 import getpass
 import socket
-import random
-from random import Random as SystemRandom
 
-from .numericutils import from_bytes
 from .numericutils import NUMERIC_TYPES
 from .threadutils import get_ident
 
-if not hasattr(random, "choices"):
-    def _choices(population, k=1):
-        result = []
-        for _ in range(k):
-            result.append(random.choice(population))
-        return result
-    setattr(random, "choices", _choices)
-
 
 DEFAULT_BASE = (2 ** 30 - 123) * 0.91
 DEFAULT_A = (2 ** 29 - 456) * 0.93
@@ -42,7 +31,7 @@ class Random(object):
         if isinstance(seed, str):
             seed = seed.encode("utf-8")
         if isinstance(seed, bytes):
-            seed = from_bytes(hashlib.sha512(seed).digest(), "big")
+            seed = int.from_bytes(hashlib.sha512(seed).digest(), "big")
         if isinstance(seed, NUMERIC_TYPES):
             return seed
         else:
@@ -134,3 +123,4 @@ def uuid1():
     return uuidgen.next()
 
 uuid3 = uuid4 = uuid5 = uuid1
+
